Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Trigger ¶
Trigger defines the interface of a trigger instance
func NewPulseTrigger ¶ added in v1.11.0
NewPulseTrigger instantiate a new pulse trigger that will execute a callback method after a determined amount of time.
Click to show internal directories.
Click to hide internal directories.