Retracted
package
Version:
v1.2.0
Opens a new window with list of versions in this module.
Published: Jul 31, 2021
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Callback func() error
Callback used as a trigger execution process.
type Trigger interface {
Close()
Timer() time.Duration
IsStopped() bool
Stop()
}
Trigger defines the interface of a trigger instance
NewPulse instantiate a new pulse trigger that will execute a
callback method after a determined amount of time.
NewRecurring instantiate a new trigger that will execute a
callback method recurrently with a defined periodicity.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.