Documentation
¶
Index ¶
Constants ¶
const ( // ContainerID defines the id to be used as the container // registration id of a validation instance, and as a base id of all other // validation package instances registered in the application container. ContainerID = gapp.ContainerID + ".validation" // ContainerParserID defines the id to be used // as the container registration id of an error parser instance. ContainerParserID = ContainerID + ".parser" )
Variables ¶
This section is empty.
Functions ¶
func NewProvider ¶
NewProvider will create a new validation provider instance
Types ¶
type Parser ¶
type Parser interface {
Parse(ctx *gin.Context, val interface{}, errs validator.ValidationErrors) (envelope.Envelope, error)
}
Parser defines the interface to an error parsing class used to convert a validation error into an envelope error
func NewParser ¶
func NewParser(strategy ParserStrategy) (Parser, error)
NewParser instantiate a new validation parser instance
type ParserStrategy ¶
type ParserStrategy func(ctx *gin.Context, val interface{}, err validator.FieldError) (envelope.Error, error)
ParserStrategy is a function type used to define a calling interface of a function responsible to parse a validation error into an envelope error information
func NewParserStrategy ¶
func NewParserStrategy(translator ut.Translator) (ParserStrategy, error)
NewParserStrategy instantiate a new default error parser strategy used by the parser to convert a validation error into an envelope error
Click to show internal directories.
Click to hide internal directories.